/*
  pin_map.h - Pin mapping configuration file
  Part of Grbl

  Copyright (c) 2013 Sungeun K. Jeon

  Grbl is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Grbl is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Grbl.  If not, see <http://www.gnu.org/licenses/>.
*/

/* The pin_map.h file serves as a central pin mapping settings file for different processor
   types, i.e. AVR 328p or AVR Mega 2560. Grbl officially supports the Arduino Uno, but the 
   other supplied pin mappings are supplied by users, so your results may vary. */

#ifndef pin_map_h
#define pin_map_h

#ifdef PIN_MAP_ARDUINO_UNO // AVR 328p, Officially supported by Grbl.

  // Serial port pins
  #define SERIAL_RX USART_RX_vect
  #define SERIAL_UDRE USART_UDRE_vect

  // NOTE: All step bit and direction pins must be on the same port.
  #define STEPPING_DDR       DDRD
  #define STEPPING_PORT      PORTD
  #define X_STEP_BIT         2  // Uno Digital Pin 2
  #define Y_STEP_BIT         3  // Uno Digital Pin 3
  #define Z_STEP_BIT         4  // Uno Digital Pin 4
  #define X_DIRECTION_BIT    5  // Uno Digital Pin 5
  #define Y_DIRECTION_BIT    6  // Uno Digital Pin 6
  #define Z_DIRECTION_BIT    7  // Uno Digital Pin 7
  #define STEP_MASK ((1<<X_STEP_BIT)|(1<<Y_STEP_BIT)|(1<<Z_STEP_BIT)) // All step bits
  #define DIRECTION_MASK ((1<<X_DIRECTION_BIT)|(1<<Y_DIRECTION_BIT)|(1<<Z_DIRECTION_BIT)) // All direction bits
  #define STEPPING_MASK (STEP_MASK | DIRECTION_MASK) // All stepping-related bits (step/direction)

  #define STEPPERS_DISABLE_DDR    DDRB
  #define STEPPERS_DISABLE_PORT   PORTB
  #define STEPPERS_DISABLE_BIT    0  // Uno Digital Pin 8
  #define STEPPERS_DISABLE_MASK (1<<STEPPERS_DISABLE_BIT)

  // NOTE: All limit bit pins must be on the same port
  #define LIMIT_DDR       DDRB
  #define LIMIT_PIN       PINB
  #define LIMIT_PORT      PORTB
  #define X_LIMIT_BIT     1  // Uno Digital Pin 9
  #define Y_LIMIT_BIT     2  // Uno Digital Pin 10
  #define Z_LIMIT_BIT     3  // Uno Digital Pin 11
  #define LIMIT_INT       PCIE0  // Pin change interrupt enable pin
  #define LIMIT_INT_vect  PCINT0_vect 
  #define LIMIT_PCMSK     PCMSK0 // Pin change interrupt register
  #define LIMIT_MASK ((1<<X_LIMIT_BIT)|(1<<Y_LIMIT_BIT)|(1<<Z_LIMIT_BIT)) // All limit bits

  #define SPINDLE_ENABLE_DDR   DDRB
  #define SPINDLE_ENABLE_PORT  PORTB
  #define SPINDLE_ENABLE_BIT   4  // Uno Digital Pin 12

  #define SPINDLE_DIRECTION_DDR   DDRB
  #define SPINDLE_DIRECTION_PORT  PORTB
  #define SPINDLE_DIRECTION_BIT   5  // Uno Digital Pin 13 (NOTE: D13 can't be pulled-high input due to LED.)

  #define COOLANT_FLOOD_DDR   DDRC
  #define COOLANT_FLOOD_PORT  PORTC
  #define COOLANT_FLOOD_BIT   3  // Uno Analog Pin 3

  // NOTE: Uno analog pins 4 and 5 are reserved for an i2c interface, and may be installed at
  // a later date if flash and memory space allows.
  // #define ENABLE_M7  // Mist coolant disabled by default. Uncomment to enable.
  #ifdef ENABLE_M7
    #define COOLANT_MIST_DDR   DDRC
    #define COOLANT_MIST_PORT  PORTC
    #define COOLANT_MIST_BIT   4 // Uno Analog Pin 4
  #endif  

  // NOTE: All pinouts pins must be on the same port
  #define PINOUT_DDR       DDRC
  #define PINOUT_PIN       PINC
  #define PINOUT_PORT      PORTC
  #define PIN_RESET        0  // Uno Analog Pin 0
  #define PIN_FEED_HOLD    1  // Uno Analog Pin 1
  #define PIN_CYCLE_START  2  // Uno Analog Pin 2
  #define PINOUT_INT       PCIE1  // Pin change interrupt enable pin
  #define PINOUT_INT_vect  PCINT1_vect
  #define PINOUT_PCMSK     PCMSK1 // Pin change interrupt register
  #define PINOUT_MASK ((1<<PIN_RESET)|(1<<PIN_FEED_HOLD)|(1<<PIN_CYCLE_START))
  
#endif


#ifdef PIN_MAP_ARDUINO_MEGA_2560 // Unsupported. Doesn't work. Supplied by @elmom.

  // Serial port pins
  #define SERIAL_RX USART0_RX_vect
  #define SERIAL_UDRE USART0_UDRE_vect

  // NOTE: All step bit and direction pins must be on the same port.
  #define STEPPING_DDR      DDRA
  #define STEPPING_PORT     PORTA
  #define STEPPING_PIN      PINA
  #define X_STEP_BIT        0 // MEGA2560 Digital Pin 22
  #define Y_STEP_BIT        1 // MEGA2560 Digital Pin 23
  #define Z_STEP_BIT        2 // MEGA2560 Digital Pin 24
  // #define C_STEP_BIT        3 // MEGA2560 Digital Pin 25
  #define X_DIRECTION_BIT   4 // MEGA2560 Digital Pin 26
  #define Y_DIRECTION_BIT   5 // MEGA2560 Digital Pin 27
  #define Z_DIRECTION_BIT   6 // MEGA2560 Digital Pin 28
  // #define C_DIRECTION_BIT   7 // MEGA2560 Digital Pin 29
  #define STEP_MASK ((1<<X_STEP_BIT)|(1<<Y_STEP_BIT)|(1<<Z_STEP_BIT)) // All step bits
  #define DIRECTION_MASK ((1<<X_DIRECTION_BIT)|(1<<Y_DIRECTION_BIT)|(1<<Z_DIRECTION_BIT)) // All direction bits
  #define STEPPING_MASK (STEP_MASK | DIRECTION_MASK) // All stepping-related bits (step/direction)

  #define STEPPERS_DISABLE_DDR   DDRC
  #define STEPPERS_DISABLE_PORT  PORTC
  #define STEPPERS_DISABLE_BIT   7 // MEGA2560 Digital Pin 30
  #define STEPPERS_DISABLE_MASK (1<<STEPPERS_DISABLE_BIT)

  // NOTE: All limit bit pins must be on the same port
  #define LIMIT_DDR       DDRC
  #define LIMIT_PORT      PORTC
  #define LIMIT_PIN       PINC
  #define X_LIMIT_BIT     6 // MEGA2560 Digital Pin 31
  #define Y_LIMIT_BIT     5 // MEGA2560 Digital Pin 32
  #define Z_LIMIT_BIT     4 // MEGA2560 Digital Pin 33
  // #define C_LIMIT_BIT     3 // MEGA2560 Digital Pin 34
  #define LIMIT_INT       PCIE0  // Pin change interrupt enable pin
  #define LIMIT_INT_vect  PCINT0_vect 
  #define LIMIT_PCMSK     PCMSK0 // Pin change interrupt register
  #define LIMIT_MASK ((1<<X_LIMIT_BIT)|(1<<Y_LIMIT_BIT)|(1<<Z_LIMIT_BIT)) // All limit bits

  #define SPINDLE_ENABLE_DDR   DDRC
  #define SPINDLE_ENABLE_PORT  PORTC
  #define SPINDLE_ENABLE_BIT   2 // MEGA2560 Digital Pin 35

  #define SPINDLE_DIRECTION_DDR   DDRC
  #define SPINDLE_DIRECTION_PORT  PORTC
  #define SPINDLE_DIRECTION_BIT   1 // MEGA2560 Digital Pin 36

  #define COOLANT_FLOOD_DDR   DDRC
  #define COOLANT_FLOOD_PORT  PORTC
  #define COOLANT_FLOOD_BIT   0 // MEGA2560 Digital Pin 37

  // #define ENABLE_M7  // Mist coolant disabled by default. Uncomment to enable.
  #ifdef ENABLE_M7
    #define COOLANT_MIST_DDR   DDRC
    #define COOLANT_MIST_PORT  PORTC
    #define COOLANT_MIST_BIT   0 // MEGA2560 Digital Pin 37
  #endif  

  // NOTE: All pinouts pins must be on the same port
  #define PINOUT_DDR       DDRC
  #define PINOUT_PIN       PINC
  #define PINOUT_PORT      PORTC
  #define PIN_RESET        0  // Uno Analog Pin 0
  #define PIN_FEED_HOLD    1  // Uno Analog Pin 1
  #define PIN_CYCLE_START  2  // Uno Analog Pin 2
  #define PINOUT_INT       PCIE1  // Pin change interrupt enable pin
  #define PINOUT_INT_vect  PCINT1_vect
  #define PINOUT_PCMSK     PCMSK1 // Pin change interrupt register
  #define PINOUT_MASK ((1<<PIN_RESET)|(1<<PIN_FEED_HOLD)|(1<<PIN_CYCLE_START))

#endif

// Custom pin map GRBL for Stepcraft 300/420/500 on ATmega328P 
// #ifdef PIN_MAP_CUSTOM_PROC
#ifdef PIN_MAP_STEPCRAFT_300_420_600

  // For a custom pin map or different processor, copy and paste one of the default pin map
  // settings above and modify it to your needs. Then, make sure the defined name is also
  // changed in the config.h file.
 
 
 /* Stepcraft SC 320/420/600 Connector 
  Signal				Pin		Row		ATmega328P
  Relais 1				 1		 1			PD2
  DirX					 2		 1			PC5
  Takt X				 3		 1			PC4
  DirY					 4		 1			PC3
  Takt Y				 5		 1			PC2
  DirZ					 6		 1			PC1
  Takt Z				 7		 1			PC0
  Dir 4. Achse			 8		 1			GND (via R100)
  Takt 4. Achse			 9		 1			GND (via R100)
  Werkzeug-Lnge		10		 1			PB2
  Fehler				11		 1			PB0
  Endschalter X/Y/Z		12		 1			PB1
  Endschalter 4. Achse	13		 1			
  Relais 2				14		 2			PD3
  frei (In)				15		 2			
  Relais 3				16		 2			PD4
  frei (Out)			17		 2			
  GND					18-25	 2			
  PE Schirm
  5V/VCC				26		 2
  
 */
 
    // Serial port pins
    #define SERIAL_RX USART_RX_vect
    #define SERIAL_UDRE USART_UDRE_vect

    // NOTE: All step bit and direction pins must be on the same port.
    #define STEPPING_DDR       DDRC
    #define STEPPING_PORT      PORTC
    #define X_DIRECTION_BIT    5  
	#define X_STEP_BIT         4  
    #define Y_DIRECTION_BIT    3  
    #define Y_STEP_BIT         2  
    #define Z_DIRECTION_BIT    1  
    #define Z_STEP_BIT         0  
    #define STEP_MASK ((1<<X_STEP_BIT)|(1<<Y_STEP_BIT)|(1<<Z_STEP_BIT)) // All step bits
    #define DIRECTION_MASK ((1<<X_DIRECTION_BIT)|(1<<Y_DIRECTION_BIT)|(1<<Z_DIRECTION_BIT)) // All direction bits
    #define STEPPING_MASK (STEP_MASK | DIRECTION_MASK) // All stepping-related bits (step/direction)

    #define STEPPERS_DISABLE_DDR    DDRB
    #define STEPPERS_DISABLE_PORT   PORTB
    #define STEPPERS_DISABLE_BIT    0  
    #define STEPPERS_DISABLE_MASK (1<<STEPPERS_DISABLE_BIT)

    // NOTE: All limit bit pins must be on the same port
    #define LIMIT_DDR       DDRB
    #define LIMIT_PIN       PINB
    #define LIMIT_PORT      PORTB
    #define X_LIMIT_BIT     1  // use same port & pin for all reference switches
    #define Y_LIMIT_BIT     1  // use same port & pin for all reference switches
    #define Z_LIMIT_BIT     1  // use same port & pin for all reference switches
    #define LIMIT_INT       PCIE0  // Pin change interrupt enable pin
    #define LIMIT_INT_vect  PCINT0_vect
    #define LIMIT_PCMSK     PCMSK0 // Pin change interrupt register
    #define LIMIT_MASK ((1<<X_LIMIT_BIT)|(1<<Y_LIMIT_BIT)|(1<<Z_LIMIT_BIT)) // All limit bits

    // SC: Relais 1
	#define SPINDLE_ENABLE_DDR   DDRD
    #define SPINDLE_ENABLE_PORT  PORTD
    #define SPINDLE_ENABLE_BIT   2  

    // SC: Relais 3 
	#define SPINDLE_DIRECTION_DDR   DDRD
    #define SPINDLE_DIRECTION_PORT  PORTD
    #define SPINDLE_DIRECTION_BIT   4 

    // SC: Relais 2
    #define COOLANT_FLOOD_DDR   DDRD
    #define COOLANT_FLOOD_PORT  PORTD
    #define COOLANT_FLOOD_BIT   3  

    // NOTE: Uno analog pins 4 and 5 are reserved for an i2c interface, and may be installed at
    // a later date if flash and memory space allows.
    // #define ENABLE_M7  // Mist coolant disabled by default. Uncomment to enable.
    #ifdef ENABLE_M7
    #define COOLANT_MIST_DDR   DDRD
    #define COOLANT_MIST_PORT  PORTD
    #define COOLANT_MIST_BIT   4
    #endif

    // NOTE: All pinouts pins must be on the same port
    #define PINOUT_DDR       DDRD
    #define PINOUT_PIN       PIND
    #define PINOUT_PORT      PORTD
    #define PIN_RESET        5  
    #define PIN_FEED_HOLD    6  
    #define PIN_CYCLE_START  7  
    #define PINOUT_INT       PCIE1  // Pin change interrupt enable pin
    #define PINOUT_INT_vect  PCINT1_vect
    #define PINOUT_PCMSK     PCMSK1 // Pin change interrupt register
    #define PINOUT_MASK ((1<<PIN_RESET)|(1<<PIN_FEED_HOLD)|(1<<PIN_CYCLE_START))
    
#endif


#endif
